### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [v0.2.0](https://github.com/nevermined-io/metadata-driver-aws/compare/v0.1.0...v0.2.0)

> 11 August 2021

- Update driver [`#1`](https://github.com/nevermined-io/metadata-driver-aws/pull/1)
- Update driver to latest version of boto3 [`3fa091a`](https://github.com/nevermined-io/metadata-driver-aws/commit/3fa091a21ac09f709ef2af541e97830e809d59b8)
- run docker in daemon mode on the CI [`31631f1`](https://github.com/nevermined-io/metadata-driver-aws/commit/31631f1605a18d70aab1aa29475cc6ec0369acf3)

#### v0.1.0

> 18 November 2020

- Initial migration [`ee6d75a`](https://github.com/nevermined-io/metadata-driver-aws/commit/ee6d75a13618163df00986fb969ed194b3fcb5ba)
- change package release name [`3e30c74`](https://github.com/nevermined-io/metadata-driver-aws/commit/3e30c74cd84abaf6f2c95d805ddc4c87cd72659c)
